from distutils.core import setup

setup(
    name = 'recurseList',
    version = '1.1.2',
    py_modules = ['recurseList'],
    author = 'Jacky',
    author_email = 'pheonix_jk@hotmail.com',
    url = 'http://www.baidu.com',
    description = 'simple printer of nested lists')
